from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Float, Int, String

Rnashapes_Eval_Nodangle_V0_1_0 = CommandToolBuilder(tool="RNAshapes_eval_nodangle", base_command=["RNAshapes_eval_nodangle"], inputs=[ToolInput(tag="in_read_energy_parameters", input_type=File(optional=True), prefix="-P", doc=InputDocumentation(doc="Read energy parameters from paramfile, instead of using the default parameter\nset. A sample parameter file should accompany your distribution.\nSee the RNAlib (Vienna-Package) documentation for details on the file format.")), ToolInput(tag="in_set_energy_range_sets_energy_range_percentage", input_type=Float(optional=True), prefix="-c", doc=InputDocumentation(doc="Set energy range (%).\nThis sets the energy range as percentage value of the minimum free energy.\nFor example, when -c 5.0 is specified, and the minimum free energy is -10.0\nkcal/mol, the energy range is set to -9.5 to -10.0 kcal/mol.\nDefault is 10.0.\n(If -e is set, -c will be ignored.)")), ToolInput(tag="in_set_energy_range_sets_energy_range_absolute", input_type=Float(optional=True), prefix="-e", doc=InputDocumentation(doc="Set energy range (kcal/mol).\nThis sets the energy range as an absolute value of the minimum free energy.\nFor example, when -e 10.0 is specified, and the minimum free energy is -10.0\nkcal/mol, the energy range is set to 0.0 to -10.0 kcal/mol.\nBy default, -c is set to 10.0.\n(If -e is set, -c will be ignored.)")), ToolInput(tag="in_set_minimal_length", input_type=Int(optional=True), prefix="-z", doc=InputDocumentation(doc="Set minimal hairpin length for K-type pseudoknots\nThe first heuristic step in computung kissing hairpins, is to find stable, non-\ninterrupted helices. These helices must have a minimal length, i.e. number\nof stacked base-pairs, of <int-value>. The higher the value, the faster the\nprogram, but also the less accurate.\nThis affects only the stems of both hairpins, not their kissing helix!\nDefault is 2. Only positive numbers are allowed.")), ToolInput(tag="in_select_pseudoknot_strategythere", input_type=String(optional=True), prefix="-s", doc=InputDocumentation(doc="select pseudoknot strategy.\nThere are four different strategies how to compute kissing hairpins (K-type pseudoknots).   We suggest A, see our paper for details.\nIf you choose 'P' only H-type pseudoknots can be computed.\nDefault is 'A', without ticks.\nAvailable strategies are 'A','B','C','D' and 'P'.")), ToolInput(tag="in_set_maximal_pseudoknot", input_type=Int(optional=True), prefix="-l", doc=InputDocumentation(doc="Set a maximal pseudoknot size.\nTo speed up computation, you can limit the number of bases involved in a\npseudoknot (and all it's loop regions) by giving <int-value>.\nBy default, there is no limitation, i.e. -l is set to input length.\nOnly positive numbers are allowed.")), ToolInput(tag="in_set_init_htype", input_type=Float(optional=True), prefix="-x", doc=InputDocumentation(doc="Set init. energy penalty for an H-type pseudoknot [9.00]\nThermodynamic energy parameters for pseudoknots have not been measured in a\nwet lab, yet. Thus, you might want to set the penalty for opening a H-type\npseudoknot yourself.\nDefault is +9.00 kcal/mol.")), ToolInput(tag="in_set_init_ktype", input_type=Float(optional=True), prefix="-y", doc=InputDocumentation(doc="Set init. energy penalty for an K-type pseudoknot [12.00]\nThermodynamic energy parameters for pseudoknots have not been measured in a\nwet lab, yet. Thus, you might want to set the penalty for opening a K-type\npseudoknot yourself.\nDefault is +12.00 kcal/mol.")), ToolInput(tag="in_set_probability_filter", input_type=Float(optional=True), prefix="-F", doc=InputDocumentation(doc="Set probability cutoff filter [0.000001]\nThis option sets a barrier for filtering out results with very low\nprobabilities during calculation. The default value here is 0.000001,\nwhich gives a significant speedup compared to a disabled filter. Note\nthat this filter can have a slight influence on the overall results. To\ndisable this filter, use option -F 0.\nFor use in outside context: mimics Viennas --bppmThreshold=<value> parameter\nSet the threshold for base pair probabilities included in the postscript output (default=`1e-5')")), ToolInput(tag="in_outside_context_write", input_type=File(optional=True), prefix="-o", doc=InputDocumentation(doc="for outside context: write dot-plot in <file>. Default is ./dotPlot.ps.")), ToolInput(tag="in_set_weight_covariance", input_type=Float(optional=True), prefix="-C", doc=InputDocumentation(doc="Set the weight of the covariance term in the energy function [1.0]")), ToolInput(tag="in_set_penalty_noncompatible", input_type=Float(optional=True), prefix="-n", doc=InputDocumentation(doc="Set the penalty for non-compatible sequences in the covariance term of the energy function [1.0]")), ToolInput(tag="in_fraction_aligned_bases", input_type=Int(optional=True), prefix="-m", doc=InputDocumentation(doc="fraction of aligned bases in two columns that must be able to actually pair [-200]")), ToolInput(tag="in_alignment_folding_use", input_type=Int(optional=True), prefix="-R", doc=InputDocumentation(doc="for alignment folding: 0 = use hamming distance for covariance\ncalculation, 1 = use ribosum scoring matrix. The matrix is chosen according\nto the minimal and maximal pairwise identities of the sequences in the\nalignment. Default is [0]")), ToolInput(tag="in_set_shape_abstraction", input_type=Int(optional=True), prefix="-q", doc=InputDocumentation(doc="Set shape abstraction level [5]")), ToolInput(tag="in_allow_base_pairs", input_type=Int(optional=True), prefix="-u", doc=InputDocumentation(doc="1 = allow lonely base pairs, 0 = don't allow them [0]")), ToolInput(tag="in_read_input_file", input_type=File(optional=True), prefix="-f", doc=InputDocumentation(doc="Read input from a file")), ToolInput(tag="in_select_alignment_consensus", input_type=Int(optional=True), prefix="-a", doc=InputDocumentation(doc="select alignment consensus representation for dot plots, aka. outside computation.\n0 = consensus, 1 = most informative sequence")), ToolInput(tag="in_this_help", input_type=Int(optional=True), prefix="-h", doc=InputDocumentation(doc="this help.\n(-[drk] [0-9]+)*")), ToolInput(tag="in_reads_file_contains", input_type=File(optional=True), prefix="-S", doc=InputDocumentation(doc="reads a file that contains chemical probing results to 'constrain' the prediction.\nThe file must contain two tabular separated columns.\nThe first addresses the affected base by an index starting at 1.\nThe second holds the measured reactivity value as a float number.")), ToolInput(tag="in_var_20", input_type=Float(optional=True), prefix="-A", doc=InputDocumentation(doc="sets the 'slope' for the RNAstructure inspired formula\nof how to combine free energies and reactivities [1.8]")), ToolInput(tag="in_b", input_type=Float(optional=True), prefix="-B", doc=InputDocumentation(doc="sets the 'intercept' for the RNAstructure inspired formula\nof how to combine free energies and reactivities [-0.6]")), ToolInput(tag="in_sets_type_used", input_type=String(optional=True), prefix="-M", doc=InputDocumentation(doc="sets the type of the chemical modifier used to probe the structure.\nvalid types are 'DMS', 'CMCT', 'SHAPE', 'diffSHAPE', 'unknown' [unknown].")), ToolInput(tag="in_sets_type_reading", input_type=File(optional=True), prefix="-N", doc=InputDocumentation(doc="sets the type of normalization when reading the pure reactivity values from the file.\nvalid types are 'centroid', 'RNAstructure', 'logplain', 'asProbabilities' [centroid].\n"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Rnashapes_Eval_Nodangle_V0_1_0().translate("wdl", allow_empty_container=True)

